summaryrefslogtreecommitdiffstats
path: root/libkmime/kmime_headers.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkmime/kmime_headers.h')
-rw-r--r--libkmime/kmime_headers.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/libkmime/kmime_headers.h b/libkmime/kmime_headers.h
index 1c980a04..40ae18b8 100644
--- a/libkmime/kmime_headers.h
+++ b/libkmime/kmime_headers.h
@@ -116,16 +116,16 @@ class KDE_EXPORT Base {
/** Create an empty header. */
Base() : e_ncCS(0), p_arent(0) {}
- /** Create an empty header with a parent-content. */
- Base(KMime::Content *parent) : e_ncCS(0), p_arent(parent) {}
+ /** Create an empty header with a tqparent-content. */
+ Base(KMime::Content *tqparent) : e_ncCS(0), p_arent(tqparent) {}
/** Destructor */
virtual ~Base() {}
- /** Return the parent of this header. */
- KMime::Content* parent() { return p_arent; }
+ /** Return the tqparent of this header. */
+ KMime::Content* tqparent() { return p_arent; }
- /** Set the parent for this header. */
+ /** Set the tqparent for this header. */
void setParent(KMime::Content *p) { p_arent=p; }
/** Parse the given string. Take care of RFC2047-encoded
@@ -239,7 +239,7 @@ private:
};
/** This is the base class for all structured header fields. It
- tqcontains parsing methods for all basic token types found in
+ contains parsing methods for all basic token types found in
rfc2822.
@section Parsing
@@ -283,10 +283,10 @@ protected:
bool writeAtom( char* & dcursor, const char * const dend, const TQString & input );
bool writeAtom( char* & dcursor, const char * const dend,
- const QPair<const char*,int> & input );
+ const TQPair<const char*,int> & input );
bool writeToken( char* & dcursor, const char * const dend, const TQString & input );
bool writeToken( char* & dcursor, const char * const dend,
- const QPair<const char*int> & input );
+ const TQPair<const char*int> & input );
bool writeGenericQuotedString( char* & dcursor, const char * const dend,
const TQString & input, bool withCRLF=false );
@@ -605,7 +605,7 @@ class KDE_EXPORT Subject : public Generics::GUnstructured {
virtual const char* type() { return "Subject"; }
bool isReply() {
- return ( asUnicodeString().find( TQString("Re:"), 0, false ) == 0 );
+ return ( asUnicodeString().tqfind( TQString("Re:"), 0, false ) == 0 );
}
};
@@ -651,7 +651,7 @@ class KDE_EXPORT Control : public Base {
virtual bool isEmpty() { return (c_trlMsg.isEmpty()); }
virtual const char* type() { return "Control"; }
- bool isCancel() { return (c_trlMsg.find("cancel", 0, false)!=-1); }
+ bool isCancel() { return (c_trlMsg.tqfind("cancel", 0, false)!=-1); }
protected:
TQCString c_trlMsg;
@@ -708,7 +708,7 @@ class KDE_EXPORT Newsgroups : public Base {
virtual const char* type() { return "Newsgroups"; }
TQCString firstGroup();
- bool isCrossposted() { return ( g_roups.find(',')>-1 ); }
+ bool isCrossposted() { return ( g_roups.tqfind(',')>-1 ); }
TQStringList getGroups();
protected:
@@ -813,7 +813,7 @@ class HeaderFactory : public TQAsciiDict<headerCreator>
private:
HeaderFactory();
~HeaderFactory() {}
- static QAsciiDict
+ static TQAsciiDict
public:
/** Create a new header object of type @p aType, or a fitting